@@ -23,7 +23,9 @@ rsvg_handle_flags_get_type (void)
   static GType etype = 0;
   if (etype == 0) {
     static const GFlagsValue values[] = {
-      { RSVG_HANDLE_FLAGS_NONE, "RSVG_HANDLE_FLAGS_NONE", "none" },
+      { RSVG_HANDLE_FLAGS_NONE, "RSVG_HANDLE_FLAGS_NONE", "flags-none" },
+      { RSVG_HANDLE_FLAG_UNLIMITED, "RSVG_HANDLE_FLAG_UNLIMITED", "flag-unlimited" },
+      { RSVG_HANDLE_FLAG_KEEP_IMAGE_DATA, "RSVG_HANDLE_FLAG_KEEP_IMAGE_DATA", "flag-keep-image-data" },
       { 0, NULL, NULL }
     };
     etype = g_flags_register_static ("RsvgHandleFlags", values);
