@@ -1,3 +1,4 @@
+/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /* vim: set ts=4 nowrap ai expandtab sw=4: */
 
 #include <glib.h>
@@ -13,10 +14,13 @@ test_crash (gconstpointer data)
     GError *error = NULL;
 
     handle = rsvg_handle_new_from_gfile_sync (file, RSVG_HANDLE_FLAGS_NONE, NULL, &error);
-    g_assert_no_error (error);
-    g_assert (handle != NULL);
-
-    g_object_unref (handle);
+    if (handle) {
+        g_assert_no_error (error);
+        g_object_unref (handle);
+    } else {
+        g_assert (error != NULL);
+        g_error_free (error);
+    }
 }
 
 int
